@@ -1,6 +1,12 @@
 #ifndef __VORBIS_H__
 #define __VORBIS_H__
 
+#include <vorbis/vorbisfile.h>
+
+#include "libbeep/vfs.h"
+
+extern ov_callbacks vorbis_callbacks;
+
 void vorbis_configure(void);
 
 void vorbis_file_info_box(char *filename);
@@ -32,4 +38,4 @@ enum {
     REPLAYGAIN_MODE_LAST
 };
 
-#endif				/* __VORBIS_H__ */
+#endif                          /* __VORBIS_H__ */
