@@ -1,5 +1,8 @@
-/*  XMMS - Cross-platform multimedia player
- *  Copyright (C) 1998-2000  Peter Alm, Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
+/*  BMP - Cross-platform multimedia player
+ *  Copyright (C) 2003-2004  BMP development team.
+ *
+ *  Based on XMMS:
+ *  Copyright (C) 1998-2003  XMMS development team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,13 +18,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #include "OSS.h"
-#include "beep/i18n.h"
+
+#include <glib.h>
+#include <glib/gi18n.h>
 
 OutputPlugin oss_op = {
     NULL,
     NULL,
-    NULL,			/* Description */
+    NULL,                       /* Description */
     oss_init,
     oss_about,
     oss_configure,
@@ -38,7 +44,8 @@ OutputPlugin oss_op = {
     oss_get_written_time,
 };
 
-OutputPlugin *get_oplugin_info(void)
+OutputPlugin *
+get_oplugin_info(void)
 {
     oss_op.description = g_strdup_printf(_("OSS Output Plugin"));
     return &oss_op;
