@@ -1,5 +1,8 @@
-/*  XMMS - Cross-platform multimedia player
- *  Copyright (C) 1998-2000  Peter Alm, Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
+/*  BMP - Cross-platform multimedia player
+ *  Copyright (C) 2003-2004  BMP development team.
+ *
+ *  Based on XMMS:
+ *  Copyright (C) 1998-2003  XMMS development team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,14 +21,23 @@
 #ifndef MONOSTEREO_H
 #define MONOSTEREO_H
 
-typedef struct {
+#include <glib.h>
+#include <gdk/gdk.h>
+
+#include "skin.h"
+#include "widget.h"
+
+#define MONO_STEREO(x)  ((MonoStereo *)(x))
+struct _MonoStereo {
     Widget ms_widget;
-    int ms_num_channels;
-    SkinIndex ms_skin_index;
-} MonoStereo;
+    gint ms_num_channels;
+    SkinPixmapId ms_skin_index;
+};
+
+typedef struct _MonoStereo MonoStereo;
 
 MonoStereo *create_monostereo(GList ** wlist, GdkPixmap * parent,
-			      GdkGC * gc, gint x, gint y, SkinIndex si);
+                              GdkGC * gc, gint x, gint y, SkinPixmapId si);
 void monostereo_set_num_channels(MonoStereo * ms, gint nch);
 
 #endif
